[![Build Status](https://travis-ci.org/figome/python-festung.svg?branch=master)][build status]
[![Version](https://img.shields.io/pypi/v/festung.svg?style=flat-square)][version]

Festung DBAPI for Python
========================

This library provides a [Database API v2.0] to [Festung].

[build status]: https://travis-ci.org/figome/python-festung
[version]: https://pypi.python.org/pypi/festung
[Database API v2.0]: https://www.python.org/dev/peps/pep-0249/
[Festung]: https://github.com/figome/festung
